==> seedsui-react-5.8.79.tgz: package/lib/DatePicker/Main/DateMain/getList.js <==
// 内库使用
import DateUtil from "./../../../DateUtil";

// 测试使用
// import { DateUtil } from 'seedsui-react'

// 数据
function getList(value, type) {
  // Year
  var years = [];
  for (var item = new Date().getFullYear() - 120; item <= new Date().getFullYear() + 120; item++) {
    years.push({
      id: item,
      name: item
    });
  }

  // Month
  var months = [];
  for (var _item = 1; _item <= 12; _item++) {
    months.push({
      id: _item,
      name: _item
    });
  }

  // Date
  var dates = [];
  for (var _item2 = 1; _item2 <= DateUtil.getDaysInMonth(value); _item2++) {
    dates.push({
      id: _item2,
      name: _item2
    });
  }

  // Hour
  var hours = [];
  for (var _item3 = 0; _item3 <= 23; _item3++) {
    hours.push({
      id: _item3,
      name: _item3
    });
  }

  // Minute
  var minutes = [];
  for (var _item4 = 0; _item4 <= 59; _item4++) {
    minutes.push({
      id: _item4,
      name: _item4
    });
  }

  // Quarter
  var quarters = [];
  for (var _item5 = 1; _item5 <= 4; _item5++) {
    quarters.push({
      id: _item5,
      name: 'Q' + _item5
    });
  }
  if (type === 'year') {
    return [years];
  }
  if (type === 'quarter') {
    return [years, quarters];
  }
  if (type === 'month') {
    return [years, months];
  }
  if (type === 'date') {
    return [years, months, dates];
  }
  if (type === 'datetime') {
    return [years, months, dates, hours, minutes];
  }
  if (type === 'time') {
    return [hours, minutes];
  }
  return null;
}
export default getList;

==> seedsui-react-5.8.90.tgz: package/lib/DatePicker/Main/DateMain/getList.js <==
// 内库使用
import DateUtil from "./../../../DateUtil";

// 测试使用
// import { DateUtil } from 'seedsui-react'

// 数据
function getList(value, type, _ref) {
  var hourStep = _ref.hourStep,
    minuteStep = _ref.minuteStep;
  if (!hourStep || typeof hourStep !== 'number') {
    // eslint-disable-next-line
    hourStep = 1;
  }
  if (!minuteStep || typeof minuteStep !== 'number') {
    // eslint-disable-next-line
    minuteStep = 1;
  }

  // Year
  var years = [];
  for (var item = new Date().getFullYear() - 120; item <= new Date().getFullYear() + 120; item++) {
    years.push({
      id: item,
      name: item
    });
  }

  // Month
  var months = [];
  for (var _item = 1; _item <= 12; _item++) {
    months.push({
      id: _item,
      name: _item
    });
  }

  // Date
  var dates = [];
  for (var _item2 = 1; _item2 <= DateUtil.getDaysInMonth(value); _item2++) {
    dates.push({
      id: _item2,
      name: _item2
    });
  }

  // Hour
  var hours = [];
  for (var _item3 = 0; _item3 <= 23; _item3 += hourStep) {
    hours.push({
      id: _item3,
      name: _item3
    });
  }

  // Minute
  var minutes = [];
  for (var _item4 = 0; _item4 <= 59; _item4 += minuteStep) {
    minutes.push({
      id: _item4,
      name: _item4
    });
  }

  // Quarter
  var quarters = [];
  for (var _item5 = 1; _item5 <= 4; _item5++) {
    quarters.push({
      id: _item5,
      name: 'Q' + _item5
    });
  }
  if (type === 'year') {
    return [years];
  }
  if (type === 'quarter') {
    return [years, quarters];
  }
  if (type === 'month') {
    return [years, months];
  }
  if (type === 'date') {
    return [years, months, dates];
  }
  if (type === 'datetime') {
    return [years, months, dates, hours, minutes];
  }
  if (type === 'time') {
    return [hours, minutes];
  }
  return null;
}
export default getList;
